# pyddb
设备调试桥

合并 adb 工具和 tidevice 工具

[English](README_EN.md)
# 感谢
[https://github.com/alibaba/taobao-iphone-device](https://github.com/alibaba/taobao-iphone-device)

[https://github.com/pdm-project/pdm](https://github.com/pdm-project/pdm)
# 许可证
MIT